summaryrefslogtreecommitdiffstats
path: root/kpovmodeler
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:12:51 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:12:51 -0600
commit65eca7929c22f0f0bc64135c02d85d1243df376c (patch)
tree5b47361590fb6693a0f6258d6a8d725856ef2ad9 /kpovmodeler
parentcd6d514066c22206c388eddbb7fbec32648dbaeb (diff)
downloadtdegraphics-65eca7929c22f0f0bc64135c02d85d1243df376c.tar.gz
tdegraphics-65eca7929c22f0f0bc64135c02d85d1243df376c.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'kpovmodeler')
-rw-r--r--kpovmodeler/pmactions.cpp36
-rw-r--r--kpovmodeler/pmactions.h6
-rw-r--r--kpovmodeler/pmdockwidget.cpp12
-rw-r--r--kpovmodeler/pmdockwidget.h10
-rw-r--r--kpovmodeler/pminsertpopup.cpp2
-rw-r--r--kpovmodeler/pminsertpopup.h2
-rw-r--r--kpovmodeler/pmlibraryobjectsearch.cpp2
-rw-r--r--kpovmodeler/pmlibraryobjectsearch.h4
-rw-r--r--kpovmodeler/pmobjectaction.h2
-rw-r--r--kpovmodeler/pmpart.cpp176
-rw-r--r--kpovmodeler/pmpart.h214
-rw-r--r--kpovmodeler/pmshell.cpp32
-rw-r--r--kpovmodeler/pmshell.h46
-rw-r--r--kpovmodeler/pmviewlayoutmanager.cpp2
-rw-r--r--kpovmodeler/pmviewlayoutmanager.h2
15 files changed, 274 insertions, 274 deletions
diff --git a/kpovmodeler/pmactions.cpp b/kpovmodeler/pmactions.cpp
index d44715e6..a49c2041 100644
--- a/kpovmodeler/pmactions.cpp
+++ b/kpovmodeler/pmactions.cpp
@@ -53,7 +53,7 @@ public:
PMComboAction::PMComboAction( const TQString& text, int accel, const TQObject* receiver, const char* member,
TQObject* parent, const char* name )
- : KAction( text, accel, parent, name )
+ : TDEAction( text, accel, parent, name )
{
m_receiver = receiver;
m_member = member;
@@ -67,12 +67,12 @@ PMComboAction::~PMComboAction( )
int PMComboAction::plug( TQWidget* w, int index )
{
- if( !w->inherits( "KToolBar" ) )
+ if( !w->inherits( "TDEToolBar" ) )
return -1;
- KToolBar* toolBar = ( KToolBar* ) w;
+ TDEToolBar* toolBar = ( TDEToolBar* ) w;
- int id = KAction::getToolButtonID( );
+ int id = TDEAction::getToolButtonID( );
TQComboBox* comboBox = new PMComboBox( toolBar );
if( m_minWidth > 0 )
@@ -101,10 +101,10 @@ int PMComboAction::plug( TQWidget* w, int index )
void PMComboAction::unplug( TQWidget *w )
{
- if( !w->inherits( "KToolBar" ) )
+ if( !w->inherits( "TDEToolBar" ) )
return;
- KToolBar *toolBar = ( KToolBar* ) w;
+ TDEToolBar *toolBar = ( TDEToolBar* ) w;
int idx = findContainer( w );
@@ -144,7 +144,7 @@ protected:
};
PMLabelAction::PMLabelAction( const TQString &text, TQObject *parent, const char *name )
- : KAction( text, 0, parent, name )
+ : TDEAction( text, 0, parent, name )
{
m_button = 0;
}
@@ -153,11 +153,11 @@ int PMLabelAction::plug( TQWidget *widget, int index )
{
//do not call the previous implementation here
- if( widget->inherits( "KToolBar" ) )
+ if( widget->inherits( "TDEToolBar" ) )
{
- KToolBar* tb = ( KToolBar* ) widget;
+ TDEToolBar* tb = ( TDEToolBar* ) widget;
- int id = KAction::getToolButtonID( );
+ int id = TDEAction::getToolButtonID( );
m_button = new PMToolBarLabel( text( ), widget );
tb->insertWidget( id, m_button->width( ), m_button, index );
@@ -174,9 +174,9 @@ int PMLabelAction::plug( TQWidget *widget, int index )
void PMLabelAction::unplug( TQWidget *widget )
{
- if( widget->inherits( "KToolBar" ) )
+ if( widget->inherits( "TDEToolBar" ) )
{
- KToolBar* bar = ( KToolBar* ) widget;
+ TDEToolBar* bar = ( TDEToolBar* ) widget;
int idx = findContainer( bar );
@@ -194,7 +194,7 @@ void PMLabelAction::unplug( TQWidget *widget )
PMSpinBoxAction::PMSpinBoxAction( const TQString& text, int accel, const TQObject* receiver, const char* member,
TQObject* parent, const char* name )
- : KAction( text, accel, parent, name )
+ : TDEAction( text, accel, parent, name )
{
m_receiver = receiver;
m_member = member;
@@ -206,12 +206,12 @@ PMSpinBoxAction::~PMSpinBoxAction( )
int PMSpinBoxAction::plug( TQWidget* w, int index )
{
- if( !w->inherits( "KToolBar" ) )
+ if( !w->inherits( "TDEToolBar" ) )
return -1;
- KToolBar* toolBar = ( KToolBar* ) w;
+ TDEToolBar* toolBar = ( TDEToolBar* ) w;
- int id = KAction::getToolButtonID( );
+ int id = TDEAction::getToolButtonID( );
TQSpinBox* spinBox = new TQSpinBox( -1000, 1000, 1, w );
toolBar->insertWidget( id, 70, spinBox, index );
@@ -234,10 +234,10 @@ int PMSpinBoxAction::plug( TQWidget* w, int index )
void PMSpinBoxAction::unplug( TQWidget *w )
{
- if( !w->inherits( "KToolBar" ) )
+ if( !w->inherits( "TDEToolBar" ) )
return;
- KToolBar *toolBar = (KToolBar *)w;
+ TDEToolBar *toolBar = (TDEToolBar *)w;
int idx = findContainer( w );
diff --git a/kpovmodeler/pmactions.h b/kpovmodeler/pmactions.h
index 937b62a7..e5b0b4c2 100644
--- a/kpovmodeler/pmactions.h
+++ b/kpovmodeler/pmactions.h
@@ -33,7 +33,7 @@ class TQToolButton;
*
* Copied from konq_actions.h, author: Simon Hausmann <hausmann@kde.org>
*/
-class PMComboAction : public KAction
+class PMComboAction : public TDEAction
{
Q_OBJECT
@@ -65,7 +65,7 @@ private:
*
* Copied from konq_actions.h, author: Simon Hausmann <hausmann@kde.org>
*/
-class PMLabelAction : public KAction
+class PMLabelAction : public TDEAction
{
Q_OBJECT
@@ -83,7 +83,7 @@ private:
/**
* Spinbox action for the toolbar.
*/
-class PMSpinBoxAction : public KAction
+class PMSpinBoxAction : public TDEAction
{
Q_OBJECT
diff --git a/kpovmodeler/pminsertpopup.cpp b/kpovmodeler/pminsertpopup.cpp
index 0f8ffb23..bcd24720 100644
--- a/kpovmodeler/pminsertpopup.cpp
+++ b/kpovmodeler/pminsertpopup.cpp
@@ -25,7 +25,7 @@ PMInsertPopup::PMInsertPopup( TQWidget* parent, bool multipleObjects,
int items, bool canInsertAllAsFirstChildren,
bool canInsertAllAsLastChildren,
bool canInsertAllAsSiblings, const char* name )
- : KPopupMenu( parent, name )
+ : TDEPopupMenu( parent, name )
{
TQString itemText;
if( multipleObjects )
diff --git a/kpovmodeler/pminsertpopup.h b/kpovmodeler/pminsertpopup.h
index 09aa796a..6f55803f 100644
--- a/kpovmodeler/pminsertpopup.h
+++ b/kpovmodeler/pminsertpopup.h
@@ -29,7 +29,7 @@
/**
* Popup menu. Ask the user where to insert new objects
*/
-class PMInsertPopup : public KPopupMenu
+class PMInsertPopup : public TDEPopupMenu
{
public:
/**
diff --git a/kpovmodeler/pmlibraryobjectsearch.cpp b/kpovmodeler/pmlibraryobjectsearch.cpp
index 30e5be5c..fe7b4fd4 100644
--- a/kpovmodeler/pmlibraryobjectsearch.cpp
+++ b/kpovmodeler/pmlibraryobjectsearch.cpp
@@ -60,7 +60,7 @@ PMLibraryObjectSearch::PMLibraryObjectSearch( TQWidget* parent ) :
// Search results
frame = new TQFrame( this );
TQHBoxLayout* hl = new TQHBoxLayout( frame, KDialog::spacingHint( ) );
- m_pFileList = new KListView( frame );
+ m_pFileList = new TDEListView( frame );
m_pFileList->addColumn( i18n( "File" ) );
m_pFileList->addColumn( i18n( "Path" ) );
m_pFileList->setFullWidth( true );
diff --git a/kpovmodeler/pmlibraryobjectsearch.h b/kpovmodeler/pmlibraryobjectsearch.h
index 0e7b0426..35b29ed2 100644
--- a/kpovmodeler/pmlibraryobjectsearch.h
+++ b/kpovmodeler/pmlibraryobjectsearch.h
@@ -29,7 +29,7 @@ class TQLineEdit;
class TQListBox;
class TQPushButton;
class PMLibraryEntryPreview;
-class KListView;
+class TDEListView;
/**
* Search widget for Library Objects.
@@ -49,7 +49,7 @@ private slots:
private:
TQLineEdit* m_pSearch;
TQPushButton* m_pSearchButton;
- KListView* m_pFileList;
+ TDEListView* m_pFileList;
PMLibraryEntryPreview* m_pPreview;
};
diff --git a/kpovmodeler/pmobjectaction.h b/kpovmodeler/pmobjectaction.h
index 5397759c..d270db9f 100644
--- a/kpovmodeler/pmobjectaction.h
+++ b/kpovmodeler/pmobjectaction.h
@@ -30,7 +30,7 @@
#include <tqptrlist.h>
#include <tqstring.h>
-class KAction;
+class TDEAction;
/**
* Helper class for object action functions.
diff --git a/kpovmodeler/pmpart.cpp b/kpovmodeler/pmpart.cpp
index 7ca0a555..011a86af 100644
--- a/kpovmodeler/pmpart.cpp
+++ b/kpovmodeler/pmpart.cpp
@@ -227,7 +227,7 @@ void PMPart::initCopyPasteActions( )
m_pPasteAction = KStdAction::paste( this, TQT_SLOT( slotEditPaste( ) ), actionCollection( ) );
m_pDeleteAction =
- new KAction( i18n( "Delete" ), "edittrash", TQt::Key_Delete,
+ new TDEAction( i18n( "Delete" ), "edittrash", TQt::Key_Delete,
this, TQT_SLOT( slotEditDelete( ) ),
actionCollection( ), "edit_delete" );
@@ -241,10 +241,10 @@ void PMPart::initCopyPasteActions( )
void PMPart::initActions( )
{
// file menu
- m_pImportAction = new KAction( i18n( "Import..." ), 0, this,
+ m_pImportAction = new TDEAction( i18n( "Import..." ), 0, this,
TQT_SLOT( slotFileImport( ) ), actionCollection( ),
"file_import" );
- m_pExportAction = new KAction( i18n( "&Export..." ), 0, this,
+ m_pExportAction = new TDEAction( i18n( "&Export..." ), 0, this,
TQT_SLOT( slotFileExport( ) ), actionCollection( ),
"file_export" );
@@ -256,11 +256,11 @@ void PMPart::initActions( )
m_pRenderComboAction->setMinimumWidth( 250 );
connect( m_pRenderComboAction, TQT_SIGNAL( plugged( ) ),
TQT_SLOT( slotRenderModeActionPlugged( ) ) );
- m_pRenderAction = new KAction( i18n( "Render" ), "pmrender", 0, this, TQT_SLOT( slotRender( ) ),
+ m_pRenderAction = new TDEAction( i18n( "Render" ), "pmrender", 0, this, TQT_SLOT( slotRender( ) ),
actionCollection( ), "view_render" );
- m_pRenderSettingsAction = new KAction( i18n( "Render Modes..." ), "pmrendersettings", 0, this, TQT_SLOT( slotRenderSettings( ) ),
+ m_pRenderSettingsAction = new TDEAction( i18n( "Render Modes..." ), "pmrendersettings", 0, this, TQT_SLOT( slotRenderSettings( ) ),
actionCollection( ), "view_render_settings" );
- m_pViewRenderWindowAction = new KAction( i18n( "Render Window" ), 0, this, TQT_SLOT( slotViewRenderWindow( ) ),
+ m_pViewRenderWindowAction = new TDEAction( i18n( "Render Window" ), 0, this, TQT_SLOT( slotViewRenderWindow( ) ),
actionCollection( ), "view_render_window" );
m_pVisibilityLabelAction = new PMLabelAction( i18n( "Visibility level:" ) + TQString( " " ), actionCollection( ), "view_visibility_label" );
m_pVisibilityLevelAction = new PMSpinBoxAction( i18n( "Visibility Level" ),
@@ -270,7 +270,7 @@ void PMPart::initActions( )
TQT_SLOT( slotVisibilityActionPlugged( ) ) );
m_pGlobalDetailLabelAction = new PMLabelAction( i18n( "Global detail:" ) + TQString( " " ), actionCollection( ), "global_detail_label" );
- m_pGlobalDetailAction = new KSelectAction( i18n("Global Detail Level"), KShortcut(), actionCollection(), "global_detail_level" );
+ m_pGlobalDetailAction = new TDESelectAction( i18n("Global Detail Level"), TDEShortcut(), actionCollection(), "global_detail_level" );
TQStringList strList;
strList.append( i18n( "Very Low" ) );
strList.append( i18n( "Low" ) );
@@ -283,264 +283,264 @@ void PMPart::initActions( )
// new objects
if( isReadWrite( ) )
{
- m_pNewGlobalSettingsAction = new KAction( i18n( "Global Settings" ), "pmglobalsettings", 0, this, TQT_SLOT( slotNewGlobalSettings( ) ),
+ m_pNewGlobalSettingsAction = new TDEAction( i18n( "Global Settings" ), "pmglobalsettings", 0, this, TQT_SLOT( slotNewGlobalSettings( ) ),
actionCollection( ), "new_globalsettings" );
m_readWriteActions.append( m_pNewGlobalSettingsAction );
- m_pNewSkySphereAction = new KAction( i18n( "Sky Sphere" ), "pmskysphere", 0, this, TQT_SLOT( slotNewSkySphere( ) ),
+ m_pNewSkySphereAction = new TDEAction( i18n( "Sky Sphere" ), "pmskysphere", 0, this, TQT_SLOT( slotNewSkySphere( ) ),
actionCollection( ), "new_skysphere" );
m_readWriteActions.append( m_pNewSkySphereAction );
- m_pNewRainbowAction = new KAction( i18n( "Rainbow" ), "pmrainbow", 0, this, TQT_SLOT( slotNewRainbow( ) ),
+ m_pNewRainbowAction = new TDEAction( i18n( "Rainbow" ), "pmrainbow", 0, this, TQT_SLOT( slotNewRainbow( ) ),
actionCollection( ), "new_rainbow" );
m_readWriteActions.append( m_pNewRainbowAction );
- m_pNewFogAction = new KAction( i18n( "Fog" ), "pmfog", 0, this, TQT_SLOT( slotNewFog( ) ),
+ m_pNewFogAction = new TDEAction( i18n( "Fog" ), "pmfog", 0, this, TQT_SLOT( slotNewFog( ) ),
actionCollection( ), "new_fog" );
m_readWriteActions.append( m_pNewFogAction );
- m_pNewInteriorAction = new KAction( i18n( "Interior" ), "pminterior", 0, this, TQT_SLOT( slotNewInterior( ) ),
+ m_pNewInteriorAction = new TDEAction( i18n( "Interior" ), "pminterior", 0, this, TQT_SLOT( slotNewInterior( ) ),
actionCollection( ), "new_interior" );
m_readWriteActions.append( m_pNewInteriorAction );
- m_pNewMediaAction = new KAction( i18n( "Media" ), "pmmedia", 0, this, TQT_SLOT( slotNewMedia( ) ),
+ m_pNewMediaAction = new TDEAction( i18n( "Media" ), "pmmedia", 0, this, TQT_SLOT( slotNewMedia( ) ),
actionCollection( ), "new_media" );
m_readWriteActions.append( m_pNewMediaAction );
- m_pNewDensityAction = new KAction( i18n( "Density" ), "pmdensity", 0, this, TQT_SLOT( slotNewDensity( ) ),
+ m_pNewDensityAction = new TDEAction( i18n( "Density" ), "pmdensity", 0, this, TQT_SLOT( slotNewDensity( ) ),
actionCollection( ), "new_density" );
m_readWriteActions.append( m_pNewDensityAction );
- m_pNewMaterialAction = new KAction( i18n( "Material" ), "pmmaterial", 0, this, TQT_SLOT( slotNewMaterial( ) ),
+ m_pNewMaterialAction = new TDEAction( i18n( "Material" ), "pmmaterial", 0, this, TQT_SLOT( slotNewMaterial( ) ),
actionCollection( ), "new_material" );
m_readWriteActions.append( m_pNewMaterialAction );
- m_pNewBoxAction = new KAction( i18n( "Box" ), "pmbox", 0, this, TQT_SLOT( slotNewBox( ) ),
+ m_pNewBoxAction = new TDEAction( i18n( "Box" ), "pmbox", 0, this, TQT_SLOT( slotNewBox( ) ),
actionCollection( ), "new_box" );
m_readWriteActions.append( m_pNewBoxAction );
- m_pNewSphereAction = new KAction( i18n( "Sphere" ), "pmsphere", 0, this, TQT_SLOT( slotNewSphere( ) ),
+ m_pNewSphereAction = new TDEAction( i18n( "Sphere" ), "pmsphere", 0, this, TQT_SLOT( slotNewSphere( ) ),
actionCollection( ), "new_sphere" );
m_readWriteActions.append( m_pNewSphereAction );
- m_pNewCylinderAction = new KAction( i18n( "Cylinder" ), "pmcylinder", 0, this, TQT_SLOT( slotNewCylinder( ) ),
+ m_pNewCylinderAction = new TDEAction( i18n( "Cylinder" ), "pmcylinder", 0, this, TQT_SLOT( slotNewCylinder( ) ),
actionCollection( ), "new_cylinder" );
m_readWriteActions.append( m_pNewCylinderAction );
- m_pNewConeAction = new KAction( i18n( "Cone" ), "pmcone", 0, this, TQT_SLOT( slotNewCone( ) ),
+ m_pNewConeAction = new TDEAction( i18n( "Cone" ), "pmcone", 0, this, TQT_SLOT( slotNewCone( ) ),
actionCollection( ), "new_cone" );
m_readWriteActions.append( m_pNewConeAction );
- m_pNewTorusAction = new KAction( i18n( "Torus" ), "pmtorus", 0, this, TQT_SLOT( slotNewTorus( ) ),
+ m_pNewTorusAction = new TDEAction( i18n( "Torus" ), "pmtorus", 0, this, TQT_SLOT( slotNewTorus( ) ),
actionCollection( ), "new_torus" );
m_readWriteActions.append( m_pNewTorusAction );
- m_pNewLatheAction = new KAction( i18n( "Lathe" ), "pmlathe", 0, this, TQT_SLOT( slotNewLathe( ) ),
+ m_pNewLatheAction = new TDEAction( i18n( "Lathe" ), "pmlathe", 0, this, TQT_SLOT( slotNewLathe( ) ),
actionCollection( ), "new_lathe" );
m_readWriteActions.append( m_pNewLatheAction );
- m_pNewPrismAction = new KAction( i18n( "Prism" ), "pmprism", 0, this, TQT_SLOT( slotNewPrism( ) ),
+ m_pNewPrismAction = new TDEAction( i18n( "Prism" ), "pmprism", 0, this, TQT_SLOT( slotNewPrism( ) ),
actionCollection( ), "new_prism" );
m_readWriteActions.append( m_pNewPrismAction );
- m_pNewSurfaceOfRevolutionAction = new KAction( i18n( "Surface of Revolution" ), "pmsor", 0, this, TQT_SLOT( slotNewSurfaceOfRevolution( ) ),
+ m_pNewSurfaceOfRevolutionAction = new TDEAction( i18n( "Surface of Revolution" ), "pmsor", 0, this, TQT_SLOT( slotNewSurfaceOfRevolution( ) ),
actionCollection( ), "new_surfaceofrevolution" );
m_readWriteActions.append( m_pNewSurfaceOfRevolutionAction );
- m_pNewSuperquadricEllipsoidAction = new KAction( i18n( "Superquadric Ellipsoid" ), "pmsqe", 0, this, TQT_SLOT( slotNewSuperquadricEllipsoid( ) ),
+ m_pNewSuperquadricEllipsoidAction = new TDEAction( i18n( "Superquadric Ellipsoid" ), "pmsqe", 0, this, TQT_SLOT( slotNewSuperquadricEllipsoid( ) ),
actionCollection( ), "new_superquadricellipsoid" );
m_readWriteActions.append( m_pNewSuperquadricEllipsoidAction );
- m_pNewJuliaFractalAction = new KAction( i18n( "Julia Fractal" ), "pmjuliafractal", 0, this, TQT_SLOT( slotNewJuliaFractal( ) ),
+ m_pNewJuliaFractalAction = new TDEAction( i18n( "Julia Fractal" ), "pmjuliafractal", 0, this, TQT_SLOT( slotNewJuliaFractal( ) ),
actionCollection( ), "new_juliafractal" );
m_readWriteActions.append( m_pNewJuliaFractalAction );
- m_pNewHeightFieldAction = new KAction( i18n( "Height Field" ), "pmheightfield", 0, this, TQT_SLOT( slotNewHeightField( ) ),
+ m_pNewHeightFieldAction = new TDEAction( i18n( "Height Field" ), "pmheightfield", 0, this, TQT_SLOT( slotNewHeightField( ) ),
actionCollection( ), "new_heightfield" );
m_readWriteActions.append( m_pNewHeightFieldAction );
- m_pNewTextAction = new KAction( i18n( "Text" ), "pmtext", 0, this, TQT_SLOT( slotNewText( ) ),
+ m_pNewTextAction = new TDEAction( i18n( "Text" ), "pmtext", 0, this, TQT_SLOT( slotNewText( ) ),
actionCollection( ), "new_text" );
m_readWriteActions.append( m_pNewTextAction );
- m_pNewBlobAction = new KAction( i18n( "Blob" ), "pmblob", 0, this, TQT_SLOT( slotNewBlob( ) ),
+ m_pNewBlobAction = new TDEAction( i18n( "Blob" ), "pmblob", 0, this, TQT_SLOT( slotNewBlob( ) ),
actionCollection( ), "new_blob" );
m_readWriteActions.append( m_pNewBlobAction );
- m_pNewBlobSphereAction = new KAction( i18n( "Blob Sphere" ), "pmblobsphere", 0, this, TQT_SLOT( slotNewBlobSphere( ) ),
+ m_pNewBlobSphereAction = new TDEAction( i18n( "Blob Sphere" ), "pmblobsphere", 0, this, TQT_SLOT( slotNewBlobSphere( ) ),
actionCollection( ), "new_blobsphere" );
m_readWriteActions.append( m_pNewBlobSphereAction );
- m_pNewBlobCylinderAction = new KAction( i18n( "Blob Cylinder" ), "pmblobcylinder", 0, this, TQT_SLOT( slotNewBlobCylinder( ) ),
+ m_pNewBlobCylinderAction = new TDEAction( i18n( "Blob Cylinder" ), "pmblobcylinder", 0, this, TQT_SLOT( slotNewBlobCylinder( ) ),
actionCollection( ), "new_blobcylinder" );
m_readWriteActions.append( m_pNewBlobCylinderAction );
- m_pNewPlaneAction = new KAction( i18n( "Plane" ), "pmplane", 0, this, TQT_SLOT( slotNewPlane( ) ),
+ m_pNewPlaneAction = new TDEAction( i18n( "Plane" ), "pmplane", 0, this, TQT_SLOT( slotNewPlane( ) ),
actionCollection( ), "new_plane" );
m_readWriteActions.append( m_pNewPlaneAction );
- m_pNewPolynomAction = new KAction( i18n( "Polynom" ), "pmpolynom", 0, this, TQT_SLOT( slotNewPolynom( ) ),
+ m_pNewPolynomAction = new TDEAction( i18n( "Polynom" ), "pmpolynom", 0, this, TQT_SLOT( slotNewPolynom( ) ),
actionCollection( ), "new_polynom" );
m_readWriteActions.append( m_pNewPolynomAction );
- m_pNewDeclareAction = new KAction( i18n( "Declaration" ), "pmdeclare", 0, this, TQT_SLOT( slotNewDeclare( ) ),
+ m_pNewDeclareAction = new TDEAction( i18n( "Declaration" ), "pmdeclare", 0, this, TQT_SLOT( slotNewDeclare( ) ),
actionCollection( ), "new_declare" );
m_readWriteActions.append( m_pNewDeclareAction );
- m_pNewObjectLinkAction = new KAction( i18n( "Object Link" ), "pmobjectlink", 0, this, TQT_SLOT( slotNewObjectLink( ) ),
+ m_pNewObjectLinkAction = new TDEAction( i18n( "Object Link" ), "pmobjectlink", 0, this, TQT_SLOT( slotNewObjectLink( ) ),
actionCollection( ), "new_objectlink" );
m_readWriteActions.append( m_pNewObjectLinkAction );
- m_pNewUnionAction = new KAction( i18n( "Union" ), "pmunion", 0, this, TQT_SLOT( slotNewUnion( ) ),
+ m_pNewUnionAction = new TDEAction( i18n( "Union" ), "pmunion", 0, this, TQT_SLOT( slotNewUnion( ) ),
actionCollection( ), "new_union" );
m_readWriteActions.append( m_pNewUnionAction );
- m_pNewIntersectionAction = new KAction( i18n( "Intersection" ), "pmintersection", 0, this, TQT_SLOT( slotNewIntersection( ) ),
+ m_pNewIntersectionAction = new TDEAction( i18n( "Intersection" ), "pmintersection", 0, this, TQT_SLOT( slotNewIntersection( ) ),
actionCollection( ), "new_intersection" );
m_readWriteActions.append( m_pNewIntersectionAction );
- m_pNewDifferenceAction = new KAction( i18n( "Difference" ), "pmdifference", 0, this, TQT_SLOT( slotNewDifference( ) ),
+ m_pNewDifferenceAction = new TDEAction( i18n( "Difference" ), "pmdifference", 0, this, TQT_SLOT( slotNewDifference( ) ),
actionCollection( ), "new_difference" );
m_readWriteActions.append( m_pNewDifferenceAction );
- m_pNewMergeAction = new KAction( i18n( "Merge" ), "pmmerge", 0, this, TQT_SLOT( slotNewMerge( ) ),
+ m_pNewMergeAction = new TDEAction( i18n( "Merge" ), "pmmerge", 0, this, TQT_SLOT( slotNewMerge( ) ),
actionCollection( ), "new_merge" );
m_readWriteActions.append( m_pNewMergeAction );
- m_pNewBoundedByAction = new KAction( i18n( "Bounded By" ), "pmboundedby", 0, this, TQT_SLOT( slotNewBoundedBy( ) ),
+ m_pNewBoundedByAction = new TDEAction( i18n( "Bounded By" ), "pmboundedby", 0, this, TQT_SLOT( slotNewBoundedBy( ) ),
actionCollection( ), "new_boundedby" );
m_readWriteActions.append( m_pNewBoundedByAction );
- m_pNewClippedByAction = new KAction( i18n( "Clipped By" ), "pmclippedby", 0, this, TQT_SLOT( slotNewClippedBy( ) ),
+ m_pNewClippedByAction = new TDEAction( i18n( "Clipped By" ), "pmclippedby", 0, this, TQT_SLOT( slotNewClippedBy( ) ),
actionCollection( ), "new_clippedby" );
m_readWriteActions.append( m_pNewClippedByAction );
- m_pNewLightAction = new KAction( i18n( "Light" ), "pmlight", 0, this, TQT_SLOT( slotNewLight( ) ),
+ m_pNewLightAction = new TDEAction( i18n( "Light" ), "pmlight", 0, this, TQT_SLOT( slotNewLight( ) ),
actionCollection( ), "new_light" );
m_readWriteActions.append( m_pNewLightAction );
- m_pNewLooksLikeAction = new KAction( i18n( "Looks Like" ), "pmlookslike", 0, this, TQT_SLOT( slotNewLooksLike( ) ),
+ m_pNewLooksLikeAction = new TDEAction( i18n( "Looks Like" ), "pmlookslike", 0, this, TQT_SLOT( slotNewLooksLike( ) ),
actionCollection( ), "new_lookslike" );
m_readWriteActions.append( m_pNewLooksLikeAction );
- m_pNewProjectedThroughAction = new KAction( i18n( "Projected Through" ), "pmprojectedthrough", 0, this, TQT_SLOT( slotNewProjectedThrough( ) ),
+ m_pNewProjectedThroughAction = new TDEAction( i18n( "Projected Through" ), "pmprojectedthrough", 0, this, TQT_SLOT( slotNewProjectedThrough( ) ),
actionCollection( ), "new_projectedthrough" );
m_readWriteActions.append( m_pNewProjectedThroughAction );
- m_pNewBicubicPatchAction = new KAction( i18n( "Bicubic Patch" ), "pmbicubicpatch", 0, this, TQT_SLOT( slotNewBicubicPatch( ) ),
+ m_pNewBicubicPatchAction = new TDEAction( i18n( "Bicubic Patch" ), "pmbicubicpatch", 0, this, TQT_SLOT( slotNewBicubicPatch( ) ),
actionCollection( ), "new_bicubicpatch" );
m_readWriteActions.append( m_pNewBicubicPatchAction );
- m_pNewDiscAction = new KAction( i18n( "Disc" ), "pmdisc", 0, this, TQT_SLOT( slotNewDisc( ) ),
+ m_pNewDiscAction = new TDEAction( i18n( "Disc" ), "pmdisc", 0, this, TQT_SLOT( slotNewDisc( ) ),
actionCollection( ), "new_disc" );
m_readWriteActions.append( m_pNewDiscAction );
- m_pNewTriangleAction = new KAction( i18n( "Triangle" ), "pmtriangle", 0, this, TQT_SLOT( slotNewTriangle( ) ),
+ m_pNewTriangleAction = new TDEAction( i18n( "Triangle" ), "pmtriangle", 0, this, TQT_SLOT( slotNewTriangle( ) ),
actionCollection( ), "new_triangle" );
m_readWriteActions.append( m_pNewTriangleAction );
- m_pNewCameraAction = new KAction( i18n( "Camera" ), "pmcamera", 0, this, TQT_SLOT( slotNewCamera( ) ),
+ m_pNewCameraAction = new TDEAction( i18n( "Camera" ), "pmcamera", 0, this, TQT_SLOT( slotNewCamera( ) ),
actionCollection( ), "new_camera" );
m_readWriteActions.append( m_pNewCameraAction );
- m_pNewTextureAction = new KAction( i18n( "Texture" ), "pmtexture", 0, this, TQT_SLOT( slotNewTexture( ) ),
+ m_pNewTextureAction = new TDEAction( i18n( "Texture" ), "pmtexture", 0, this, TQT_SLOT( slotNewTexture( ) ),
actionCollection( ), "new_texture" );
m_readWriteActions.append( m_pNewTextureAction );
- m_pNewPigmentAction = new KAction( i18n( "Pigment" ), "pmpigment", 0, this, TQT_SLOT( slotNewPigment( ) ),
+ m_pNewPigmentAction = new TDEAction( i18n( "Pigment" ), "pmpigment", 0, this, TQT_SLOT( slotNewPigment( ) ),
actionCollection( ), "new_pigment" );
m_readWriteActions.append( m_pNewPigmentAction );
- m_pNewNormalAction = new KAction( i18n( "Normal" ), "pmnormal", 0, this, TQT_SLOT( slotNewNormal( ) ),
+ m_pNewNormalAction = new TDEAction( i18n( "Normal" ), "pmnormal", 0, this, TQT_SLOT( slotNewNormal( ) ),
actionCollection( ), "new_normal" );
m_readWriteActions.append( m_pNewNormalAction );
- m_pNewSolidColorAction = new KAction( i18n( "Solid Color" ), "pmsolidcolor", 0, this, TQT_SLOT( slotNewSolidColor( ) ),
+ m_pNewSolidColorAction = new TDEAction( i18n( "Solid Color" ), "pmsolidcolor", 0, this, TQT_SLOT( slotNewSolidColor( ) ),
actionCollection( ), "new_solidcolor" );
m_readWriteActions.append( m_pNewSolidColorAction );
- m_pNewTextureListAction = new KAction( i18n( "Texture List" ), "pmtexturelist", 0, this, TQT_SLOT( slotNewTextureList( ) ),
+ m_pNewTextureListAction = new TDEAction( i18n( "Texture List" ), "pmtexturelist", 0, this, TQT_SLOT( slotNewTextureList( ) ),
actionCollection( ), "new_texturelist" );
m_readWriteActions.append( m_pNewTextureListAction );
- m_pNewColorListAction = new KAction( i18n( "Color List" ), "pmcolorlist", 0, this, TQT_SLOT( slotNewColorList( ) ),
+ m_pNewColorListAction = new TDEAction( i18n( "Color List" ), "pmcolorlist", 0, this, TQT_SLOT( slotNewColorList( ) ),
actionCollection( ), "new_colorlist" );
m_readWriteActions.append( m_pNewColorListAction );
- m_pNewPigmentListAction = new KAction( i18n( "Pigment List" ), "pmpigmentlist", 0, this, TQT_SLOT( slotNewPigmentList( ) ),
+ m_pNewPigmentListAction = new TDEAction( i18n( "Pigment List" ), "pmpigmentlist", 0, this, TQT_SLOT( slotNewPigmentList( ) ),
actionCollection( ), "new_pigmentlist" );
m_readWriteActions.append( m_pNewPigmentListAction );
- m_pNewNormalListAction = new KAction( i18n( "Normal List" ), "pmnormallist", 0, this, TQT_SLOT( slotNewNormalList( ) ),
+ m_pNewNormalListAction = new TDEAction( i18n( "Normal List" ), "pmnormallist", 0, this, TQT_SLOT( slotNewNormalList( ) ),
actionCollection( ), "new_normallist" );
m_readWriteActions.append( m_pNewNormalListAction );
- m_pNewDensityListAction = new KAction( i18n( "Density List" ), "pmdensitylist", 0, this, TQT_SLOT( slotNewDensityList( ) ),
+ m_pNewDensityListAction = new TDEAction( i18n( "Density List" ), "pmdensitylist", 0, this, TQT_SLOT( slotNewDensityList( ) ),
actionCollection( ), "new_densitylist" );
m_readWriteActions.append( m_pNewDensityListAction );
- m_pNewFinishAction = new KAction( i18n( "Finish" ), "pmfinish", 0, this, TQT_SLOT( slotNewFinish( ) ),
+ m_pNewFinishAction = new TDEAction( i18n( "Finish" ), "pmfinish", 0, this, TQT_SLOT( slotNewFinish( ) ),
actionCollection( ), "new_finish" );
m_readWriteActions.append( m_pNewFinishAction );
- m_pNewPatternAction = new KAction( i18n( "Pattern" ), "pmpattern", 0, this, TQT_SLOT( slotNewPattern( ) ),
+ m_pNewPatternAction = new TDEAction( i18n( "Pattern" ), "pmpattern", 0, this, TQT_SLOT( slotNewPattern( ) ),
actionCollection( ), "new_pattern" );
m_readWriteActions.append( m_pNewPatternAction );
- m_pNewBlendMapModifiersAction = new KAction( i18n( "Blend Map Modifiers" ), "pmblendmapmodifiers", 0, this, TQT_SLOT( slotNewBlendMapModifiers( ) ),
+ m_pNewBlendMapModifiersAction = new TDEAction( i18n( "Blend Map Modifiers" ), "pmblendmapmodifiers", 0, this, TQT_SLOT( slotNewBlendMapModifiers( ) ),
actionCollection( ), "new_blendmapmodifiers" );
m_readWriteActions.append( m_pNewBlendMapModifiersAction );
- m_pNewTextureMapAction = new KAction( i18n( "Texture Map" ), "pmtexturemap", 0, this, TQT_SLOT( slotNewTextureMap( ) ),
+ m_pNewTextureMapAction = new TDEAction( i18n( "Texture Map" ), "pmtexturemap", 0, this, TQT_SLOT( slotNewTextureMap( ) ),
actionCollection( ), "new_texturemap" );
m_readWriteActions.append( m_pNewTextureMapAction );
- m_pNewMaterialMapAction = new KAction( i18n( "Material Map" ), "pmmaterialmap", 0, this, TQT_SLOT( slotNewMaterialMap( ) ),
+ m_pNewMaterialMapAction = new TDEAction( i18n( "Material Map" ), "pmmaterialmap", 0, this, TQT_SLOT( slotNewMaterialMap( ) ),
actionCollection( ), "new_materialmap" );
m_readWriteActions.append( m_pNewMaterialMapAction );
- m_pNewPigmentMapAction = new KAction( i18n( "Pigment Map" ), "pmpigmentmap", 0, this, TQT_SLOT( slotNewPigmentMap( ) ),
+ m_pNewPigmentMapAction = new TDEAction( i18n( "Pigment Map" ), "pmpigmentmap", 0, this, TQT_SLOT( slotNewPigmentMap( ) ),
actionCollection( ), "new_pigmentmap" );
m_readWriteActions.append( m_pNewPigmentMapAction );
- m_pNewColorMapAction = new KAction( i18n( "Color Map" ), "pmcolormap", 0, this, TQT_SLOT( slotNewColorMap( ) ),
+ m_pNewColorMapAction = new TDEAction( i18n( "Color Map" ), "pmcolormap", 0, this, TQT_SLOT( slotNewColorMap( ) ),
actionCollection( ), "new_colormap" );
m_readWriteActions.append( m_pNewColorMapAction );
- m_pNewNormalMapAction = new KAction( i18n( "Normal Map" ), "pmnormalmap", 0, this, TQT_SLOT( slotNewNormalMap( ) ),
+ m_pNewNormalMapAction = new TDEAction( i18n( "Normal Map" ), "pmnormalmap", 0, this, TQT_SLOT( slotNewNormalMap( ) ),
actionCollection( ), "new_normalmap" );
m_readWriteActions.append( m_pNewNormalMapAction );
- m_pNewBumpMapAction = new KAction( i18n( "Bump Map" ), "pmbumpmap", 0, this, TQT_SLOT( slotNewBumpMap( ) ),
+ m_pNewBumpMapAction = new TDEAction( i18n( "Bump Map" ), "pmbumpmap", 0, this, TQT_SLOT( slotNewBumpMap( ) ),
actionCollection( ), "new_bumpmap" );
m_readWriteActions.append( m_pNewBumpMapAction );
- m_pNewSlopeMapAction = new KAction( i18n( "Slope Map" ), "pmslopemap", 0, this, TQT_SLOT( slotNewSlopeMap( ) ),
+ m_pNewSlopeMapAction = new TDEAction( i18n( "Slope Map" ), "pmslopemap", 0, this, TQT_SLOT( slotNewSlopeMap( ) ),
actionCollection( ), "new_slopemap" );
m_readWriteActions.append( m_pNewSlopeMapAction );
- m_pNewDensityMapAction = new KAction( i18n( "Density Map" ), "pmdensitymap", 0, this, TQT_SLOT( slotNewDensityMap( ) ),
+ m_pNewDensityMapAction = new TDEAction( i18n( "Density Map" ), "pmdensitymap", 0, this, TQT_SLOT( slotNewDensityMap( ) ),
actionCollection( ), "new_densitymap" );
m_readWriteActions.append( m_pNewDensityMapAction );
- m_pNewSlopeAction = new KAction( i18n( "Slope" ), "pmslope", 0, this, TQT_SLOT( slotNewSlope( ) ),
+ m_pNewSlopeAction = new TDEAction( i18n( "Slope" ), "pmslope", 0, this, TQT_SLOT( slotNewSlope( ) ),
actionCollection( ), "new_slope" );
m_readWriteActions.append( m_pNewSlopeAction );
- m_pNewWarpAction = new KAction( i18n( "Warp" ), "pmwarp", 0, this, TQT_SLOT( slotNewWarp( ) ),
+ m_pNewWarpAction = new TDEAction( i18n( "Warp" ), "pmwarp", 0, this, TQT_SLOT( slotNewWarp( ) ),
actionCollection( ), "new_warp" );
m_readWriteActions.append( m_pNewWarpAction );
- m_pNewImageMapAction = new KAction( i18n( "Image Map" ), "pmimagemap", 0, this, TQT_SLOT( slotNewImageMap( ) ),
+ m_pNewImageMapAction = new TDEAction( i18n( "Image Map" ), "pmimagemap", 0, this, TQT_SLOT( slotNewImageMap( ) ),
actionCollection( ), "new_imagemap" );
m_readWriteActions.append( m_pNewImageMapAction );
- m_pNewQuickColorAction = new KAction( i18n( "QuickColor" ), "pmquickcolor", 0, this, TQT_SLOT( slotNewQuickColor( ) ),
+ m_pNewQuickColorAction = new TDEAction( i18n( "QuickColor" ), "pmquickcolor", 0, this, TQT_SLOT( slotNewQuickColor( ) ),
actionCollection( ), "new_quickcolor" );
m_readWriteActions.append( m_pNewQuickColorAction );
- m_pNewTranslateAction = new KAction( i18n( "Translate" ), "pmtranslate", 0, this, TQT_SLOT( slotNewTranslate( ) ),
+ m_pNewTranslateAction = new TDEAction( i18n( "Translate" ), "pmtranslate", 0, this, TQT_SLOT( slotNewTranslate( ) ),
actionCollection( ), "new_translate" );
m_readWriteActions.append( m_pNewTranslateAction );
- m_pNewScaleAction = new KAction( i18n( "Scale" ), "pmscale", 0, this, TQT_SLOT( slotNewScale( ) ),
+ m_pNewScaleAction = new TDEAction( i18n( "Scale" ), "pmscale", 0, this, TQT_SLOT( slotNewScale( ) ),
actionCollection( ), "new_scale" );
m_readWriteActions.append( m_pNewScaleAction );
- m_pNewRotateAction = new KAction( i18n( "Rotate" ), "pmrotate", 0, this, TQT_SLOT( slotNewRotate( ) ),
+ m_pNewRotateAction = new TDEAction( i18n( "Rotate" ), "pmrotate", 0, this, TQT_SLOT( slotNewRotate( ) ),
actionCollection( ), "new_rotate" );
m_readWriteActions.append( m_pNewRotateAction );
- m_pNewMatrixAction = new KAction( i18n( "Matrix" ), "pmmatrix", 0, this, TQT_SLOT( slotNewMatrix( ) ),
+ m_pNewMatrixAction = new TDEAction( i18n( "Matrix" ), "pmmatrix", 0, this, TQT_SLOT( slotNewMatrix( ) ),
actionCollection( ), "new_povraymatrix" );
m_readWriteActions.append( m_pNewMatrixAction );
- m_pNewCommentAction = new KAction( i18n( "Comment" ), "pmcomment", 0, this, TQT_SLOT( slotNewComment( ) ),
+ m_pNewCommentAction = new TDEAction( i18n( "Comment" ), "pmcomment", 0, this, TQT_SLOT( slotNewComment( ) ),
actionCollection( ), "new_comment" );
m_readWriteActions.append( m_pNewCommentAction );
- m_pNewRawAction = new KAction( i18n( "Raw Povray" ), "pmraw", 0, this, TQT_SLOT( slotNewRaw( ) ),
+ m_pNewRawAction = new TDEAction( i18n( "Raw Povray" ), "pmraw", 0, this, TQT_SLOT( slotNewRaw( ) ),
actionCollection( ), "new_raw" );
m_readWriteActions.append( m_pNewRawAction );
// POV-Ray 3.5 objects
- m_pNewIsoSurfaceAction = new KAction( i18n( "Iso Surface" ), "pmisosurface", 0, this, TQT_SLOT( slotNewIsoSurface( ) ),
+ m_pNewIsoSurfaceAction = new TDEAction( i18n( "Iso Surface" ), "pmisosurface", 0, this, TQT_SLOT( slotNewIsoSurface( ) ),
actionCollection( ), "new_isosurface" );
m_readWriteActions.append( m_pNewIsoSurfaceAction );
- m_pNewRadiosityAction = new KAction( i18n( "Radiosity" ), "pmradiosity", 0, this, TQT_SLOT( slotNewRadiosity( ) ),
+ m_pNewRadiosityAction = new TDEAction( i18n( "Radiosity" ), "pmradiosity", 0, this, TQT_SLOT( slotNewRadiosity( ) ),
actionCollection( ), "new_radiosity" );
m_readWriteActions.append( m_pNewRadiosityAction );
- m_pNewGlobalPhotonsAction = new KAction( i18n( "Global Photons" ), "pmglobalphotons", 0, this, TQT_SLOT( slotNewGlobalPhotons( ) ),
+ m_pNewGlobalPhotonsAction = new TDEAction( i18n( "Global Photons" ), "pmglobalphotons", 0, this, TQT_SLOT( slotNewGlobalPhotons( ) ),
actionCollection( ), "new_globalphotons" );
m_readWriteActions.append( m_pNewGlobalPhotonsAction );
- m_pNewPhotonsAction = new KAction( i18n( "Photons" ), "pmphotons", 0, this, TQT_SLOT( slotNewPhotons( ) ),
+ m_pNewPhotonsAction = new TDEAction( i18n( "Photons" ), "pmphotons", 0, this, TQT_SLOT( slotNewPhotons( ) ),
actionCollection( ), "new_photons" );
m_readWriteActions.append( m_pNewPhotonsAction );
- m_pNewLightGroupAction = new KAction( i18n( "Light Group" ), "pmlightgroup", 0, this, TQT_SLOT( slotNewLightGroup( ) ),
+ m_pNewLightGroupAction = new TDEAction( i18n( "Light Group" ), "pmlightgroup", 0, this, TQT_SLOT( slotNewLightGroup( ) ),
actionCollection( ), "new_lightgroup" );
m_readWriteActions.append( m_pNewLightGroupAction );
- m_pNewInteriorTextureAction = new KAction( i18n( "Interior Texture" ), "pminteriortexture", 0, this, TQT_SLOT( slotNewInteriorTexture( ) ),
+ m_pNewInteriorTextureAction = new TDEAction( i18n( "Interior Texture" ), "pminteriortexture", 0, this, TQT_SLOT( slotNewInteriorTexture( ) ),
actionCollection( ), "new_interiortexture" );
m_readWriteActions.append( m_pNewInteriorTextureAction );
- m_pNewSphereSweepAction = new KAction( i18n( "Sphere Sweep" ), "pmspheresweep", 0, this, TQT_SLOT( slotNewSphereSweep( ) ),
+ m_pNewSphereSweepAction = new TDEAction( i18n( "Sphere Sweep" ), "pmspheresweep", 0, this, TQT_SLOT( slotNewSphereSweep( ) ),
actionCollection( ), "new_spheresweep" );
m_readWriteActions.append( m_pNewSphereSweepAction );
- m_pNewMeshAction = new KAction( i18n( "Mesh" ), "pmmesh", 0, this, TQT_SLOT( slotNewMesh( ) ),
+ m_pNewMeshAction = new TDEAction( i18n( "Mesh" ), "pmmesh", 0, this, TQT_SLOT( slotNewMesh( ) ),
actionCollection( ), "new_mesh" );
m_readWriteActions.append( m_pNewMeshAction );
#ifdef KPM_WITH_OBJECT_LIBRARY
- m_pSearchLibraryObjectAction = new KAction( i18n( "Search Object" ), "pmsearchlibrary", 0, this, TQT_SLOT( slotSearchLibraryObject( ) ),
+ m_pSearchLibraryObjectAction = new TDEAction( i18n( "Search Object" ), "pmsearchlibrary", 0, this, TQT_SLOT( slotSearchLibraryObject( ) ),
actionCollection( ), "search_library_object" );
m_readWriteActions.append( m_pSearchLibraryObjectAction );
#endif
@@ -657,7 +657,7 @@ void PMPart::updateNewObjectActions( )
{
TQPtrListIterator<PMMetaObject> it =
m_pPrototypeManager->prototypeIterator( );
- KAction* action;
+ TDEAction* action;
bool enable;
bool readWriteParent = false;
@@ -715,7 +715,7 @@ void PMPart::updateNewObjectActions( )
void PMPart::disableReadWriteActions( )
{
- TQPtrListIterator<KAction> it( m_readWriteActions);
+ TQPtrListIterator<TDEAction> it( m_readWriteActions);
for( ; it.current( ); ++it )
it.current( )->setEnabled( false );
}
diff --git a/kpovmodeler/pmpart.h b/kpovmodeler/pmpart.h
index 9a4444bd..4758d51c 100644
--- a/kpovmodeler/pmpart.h
+++ b/kpovmodeler/pmpart.h
@@ -57,8 +57,8 @@ class PMInsertRuleSystem;
class PMIOManager;
class TQMimeSource;
-class KAction;
-class KSelectAction;
+class TDEAction;
+class TDESelectAction;
class PMComboAction;
class PMSpinBoxAction;
class PMLabelAction;
@@ -903,120 +903,120 @@ private:
bool m_onlyCopyPaste;
// the actions
- KAction* m_pImportAction;
- KAction* m_pExportAction;
-
- KAction* m_pCutAction;
- KAction* m_pCopyAction;
- KAction* m_pPasteAction;
- KAction* m_pUndoAction;
- KAction* m_pRedoAction;
- KAction* m_pDeleteAction;
-
- KAction* m_pNewGlobalSettingsAction;
- KAction* m_pNewSkySphereAction;
- KAction* m_pNewRainbowAction;
- KAction* m_pNewFogAction;
- KAction* m_pNewInteriorAction;
- KAction* m_pNewMediaAction;
- KAction* m_pNewDensityAction;
- KAction* m_pNewMaterialAction;
- KAction* m_pNewBoxAction;
- KAction* m_pNewSphereAction;
- KAction* m_pNewCylinderAction;
- KAction* m_pNewConeAction;
- KAction* m_pNewTorusAction;
- KAction* m_pNewLatheAction;
- KAction* m_pNewPrismAction;
- KAction* m_pNewSurfaceOfRevolutionAction;
- KAction* m_pNewSuperquadricEllipsoidAction;
- KAction* m_pNewJuliaFractalAction;
- KAction* m_pNewHeightFieldAction;
- KAction* m_pNewTextAction;
-
- KAction* m_pNewBlobAction;
- KAction* m_pNewBlobSphereAction;
- KAction* m_pNewBlobCylinderAction;
-
- KAction* m_pNewPlaneAction;
- KAction* m_pNewPolynomAction;
-
- KAction* m_pNewDeclareAction;
- KAction* m_pNewObjectLinkAction;
-
- KAction* m_pNewUnionAction;
- KAction* m_pNewDifferenceAction;
- KAction* m_pNewIntersectionAction;
- KAction* m_pNewMergeAction;
-
- KAction* m_pNewBoundedByAction;
- KAction* m_pNewClippedByAction;
-
- KAction* m_pNewBicubicPatchAction;
- KAction* m_pNewDiscAction;
- KAction* m_pNewTriangleAction;
-
- KAction* m_pNewLightAction;
- KAction* m_pNewLooksLikeAction;
- KAction* m_pNewProjectedThroughAction;
-
- KAction* m_pNewCameraAction;
-
- KAction* m_pNewTextureAction;
- KAction* m_pNewPigmentAction;
- KAction* m_pNewNormalAction;
- KAction* m_pNewSolidColorAction;
- KAction* m_pNewTextureListAction;
- KAction* m_pNewColorListAction;
- KAction* m_pNewPigmentListAction;
- KAction* m_pNewNormalListAction;
- KAction* m_pNewDensityListAction;
- KAction* m_pNewFinishAction;
- KAction* m_pNewPatternAction;
- KAction* m_pNewBlendMapModifiersAction;
- KAction* m_pNewTextureMapAction;
- KAction* m_pNewMaterialMapAction;
- KAction* m_pNewPigmentMapAction;
- KAction* m_pNewColorMapAction;
- KAction* m_pNewNormalMapAction;
- KAction* m_pNewBumpMapAction;
- KAction* m_pNewSlopeMapAction;
- KAction* m_pNewDensityMapAction;
- KAction* m_pNewSlopeAction;
- KAction* m_pNewWarpAction;
- KAction* m_pNewImageMapAction;
- KAction* m_pNewQuickColorAction;
-
- KAction* m_pNewTranslateAction;
- KAction* m_pNewScaleAction;
- KAction* m_pNewRotateAction;
- KAction* m_pNewMatrixAction;
-
- KAction* m_pNewCommentAction;
- KAction* m_pNewRawAction;
+ TDEAction* m_pImportAction;
+ TDEAction* m_pExportAction;
+
+ TDEAction* m_pCutAction;
+ TDEAction* m_pCopyAction;
+ TDEAction* m_pPasteAction;
+ TDEAction* m_pUndoAction;
+ TDEAction* m_pRedoAction;
+ TDEAction* m_pDeleteAction;
+
+ TDEAction* m_pNewGlobalSettingsAction;
+ TDEAction* m_pNewSkySphereAction;
+ TDEAction* m_pNewRainbowAction;
+ TDEAction* m_pNewFogAction;
+ TDEAction* m_pNewInteriorAction;
+ TDEAction* m_pNewMediaAction;
+ TDEAction* m_pNewDensityAction;
+ TDEAction* m_pNewMaterialAction;
+ TDEAction* m_pNewBoxAction;
+ TDEAction* m_pNewSphereAction;
+ TDEAction* m_pNewCylinderAction;
+ TDEAction* m_pNewConeAction;
+ TDEAction* m_pNewTorusAction;
+ TDEAction* m_pNewLatheAction;
+ TDEAction* m_pNewPrismAction;
+ TDEAction* m_pNewSurfaceOfRevolutionAction;
+ TDEAction* m_pNewSuperquadricEllipsoidAction;
+ TDEAction* m_pNewJuliaFractalAction;
+ TDEAction* m_pNewHeightFieldAction;
+ TDEAction* m_pNewTextAction;
+
+ TDEAction* m_pNewBlobAction;
+ TDEAction* m_pNewBlobSphereAction;
+ TDEAction* m_pNewBlobCylinderAction;
+
+ TDEAction* m_pNewPlaneAction;
+ TDEAction* m_pNewPolynomAction;
+
+ TDEAction* m_pNewDeclareAction;
+ TDEAction* m_pNewObjectLinkAction;
+
+ TDEAction* m_pNewUnionAction;
+ TDEAction* m_pNewDifferenceAction;
+ TDEAction* m_pNewIntersectionAction;
+ TDEAction* m_pNewMergeAction;
+
+ TDEAction* m_pNewBoundedByAction;
+ TDEAction* m_pNewClippedByAction;
+
+ TDEAction* m_pNewBicubicPatchAction;
+ TDEAction* m_pNewDiscAction;
+ TDEAction* m_pNewTriangleAction;
+
+ TDEAction* m_pNewLightAction;
+ TDEAction* m_pNewLooksLikeAction;
+ TDEAction* m_pNewProjectedThroughAction;
+
+ TDEAction* m_pNewCameraAction;
+
+ TDEAction* m_pNewTextureAction;
+ TDEAction* m_pNewPigmentAction;
+ TDEAction* m_pNewNormalAction;
+ TDEAction* m_pNewSolidColorAction;
+ TDEAction* m_pNewTextureListAction;
+ TDEAction* m_pNewColorListAction;
+ TDEAction* m_pNewPigmentListAction;
+ TDEAction* m_pNewNormalListAction;
+ TDEAction* m_pNewDensityListAction;
+ TDEAction* m_pNewFinishAction;
+ TDEAction* m_pNewPatternAction;
+ TDEAction* m_pNewBlendMapModifiersAction;
+ TDEAction* m_pNewTextureMapAction;
+ TDEAction* m_pNewMaterialMapAction;
+ TDEAction* m_pNewPigmentMapAction;
+ TDEAction* m_pNewColorMapAction;
+ TDEAction* m_pNewNormalMapAction;
+ TDEAction* m_pNewBumpMapAction;
+ TDEAction* m_pNewSlopeMapAction;
+ TDEAction* m_pNewDensityMapAction;
+ TDEAction* m_pNewSlopeAction;
+ TDEAction* m_pNewWarpAction;
+ TDEAction* m_pNewImageMapAction;
+ TDEAction* m_pNewQuickColorAction;
+
+ TDEAction* m_pNewTranslateAction;
+ TDEAction* m_pNewScaleAction;
+ TDEAction* m_pNewRotateAction;
+ TDEAction* m_pNewMatrixAction;
+
+ TDEAction* m_pNewCommentAction;
+ TDEAction* m_pNewRawAction;
// POV-Ray 3.5 objects
- KAction* m_pNewIsoSurfaceAction;
- KAction* m_pNewRadiosityAction;
- KAction* m_pNewGlobalPhotonsAction;
- KAction* m_pNewPhotonsAction;
- KAction* m_pNewLightGroupAction;
- KAction* m_pNewInteriorTextureAction;
- KAction* m_pNewSphereSweepAction;
- KAction* m_pNewMeshAction;
+ TDEAction* m_pNewIsoSurfaceAction;
+ TDEAction* m_pNewRadiosityAction;
+ TDEAction* m_pNewGlobalPhotonsAction;
+ TDEAction* m_pNewPhotonsAction;
+ TDEAction* m_pNewLightGroupAction;
+ TDEAction* m_pNewInteriorTextureAction;
+ TDEAction* m_pNewSphereSweepAction;
+ TDEAction* m_pNewMeshAction;
- KAction* m_pSearchLibraryObjectAction;
+ TDEAction* m_pSearchLibraryObjectAction;
PMComboAction* m_pRenderComboAction;
- KAction* m_pRenderSettingsAction;
- KAction* m_pViewRenderWindowAction;
- KAction* m_pRenderAction;
+ TDEAction* m_pRenderSettingsAction;
+ TDEAction* m_pViewRenderWindowAction;
+ TDEAction* m_pRenderAction;
PMSpinBoxAction* m_pVisibilityLevelAction;
PMLabelAction* m_pVisibilityLabelAction;
- KSelectAction* m_pGlobalDetailAction;
+ TDESelectAction* m_pGlobalDetailAction;
PMLabelAction* m_pGlobalDetailLabelAction;
- TQPtrList<KAction> m_readWriteActions;
+ TQPtrList<TDEAction> m_readWriteActions;
PMPrototypeManager* m_pPrototypeManager;
PMInsertRuleSystem* m_pInsertRuleSystem;
diff --git a/kpovmodeler/pmshell.cpp b/kpovmodeler/pmshell.cpp
index 35cd78cf..86dea89b 100644
--- a/kpovmodeler/pmshell.cpp
+++ b/kpovmodeler/pmshell.cpp
@@ -108,7 +108,7 @@ void PMShell::setupActions( )
KStdAction::close( TQT_TQOBJECT(this), TQT_SLOT( slotFileClose( ) ), actionCollection( ) );
KStdAction::quit( TQT_TQOBJECT(this), TQT_SLOT( close( ) ), actionCollection( ) );
- m_pPathAction = new KToggleAction( i18n( "Show &Path" ), 0, TQT_TQOBJECT(this),
+ m_pPathAction = new TDEToggleAction( i18n( "Show &Path" ), 0, TQT_TQOBJECT(this),
TQT_SLOT( slotShowPath( ) ), actionCollection( ),
"options_show_path" );
m_pPathAction->setCheckedState(i18n("Hide &Path"));
@@ -124,50 +124,50 @@ void PMShell::setupActions( )
actionCollection( ) );
KStdAction::preferences( TQT_TQOBJECT(this), TQT_SLOT( slotSettings( ) ), actionCollection( ) );
- m_pNewTopViewAction = new KAction( i18n( "New Top View" ), 0, TQT_TQOBJECT(this),
+ m_pNewTopViewAction = new TDEAction( i18n( "New Top View" ), 0, TQT_TQOBJECT(this),
TQT_SLOT( slotNewTopView( ) ),
actionCollection( ), "view_new_topview" );
- m_pNewBottomViewAction = new KAction( i18n( "New Bottom View" ), 0, TQT_TQOBJECT(this),
+ m_pNewBottomViewAction = new TDEAction( i18n( "New Bottom View" ), 0, TQT_TQOBJECT(this),
TQT_SLOT( slotNewBottomView( ) ),
actionCollection( ), "view_new_bottomview" );
- m_pNewLeftViewAction = new KAction( i18n( "New Left View" ), 0, TQT_TQOBJECT(this),
+ m_pNewLeftViewAction = new TDEAction( i18n( "New Left View" ), 0, TQT_TQOBJECT(this),
TQT_SLOT( slotNewLeftView( ) ),
actionCollection( ), "view_new_leftview" );
- m_pNewRightViewAction = new KAction( i18n( "New Right View" ), 0, TQT_TQOBJECT(this),
+ m_pNewRightViewAction = new TDEAction( i18n( "New Right View" ), 0, TQT_TQOBJECT(this),
TQT_SLOT( slotNewRightView( ) ),
actionCollection( ), "view_new_rightview" );
- m_pNewFrontViewAction = new KAction( i18n( "New Front View" ), 0, TQT_TQOBJECT(this),
+ m_pNewFrontViewAction = new TDEAction( i18n( "New Front View" ), 0, TQT_TQOBJECT(this),
TQT_SLOT( slotNewFrontView( ) ),
actionCollection( ), "view_new_frontview" );
- m_pNewBackViewAction = new KAction( i18n( "New Back View" ), 0, TQT_TQOBJECT(this),
+ m_pNewBackViewAction = new TDEAction( i18n( "New Back View" ), 0, TQT_TQOBJECT(this),
TQT_SLOT( slotNewBackView( ) ),
actionCollection( ), "view_new_back_view" );
- m_pNewCameraViewAction = new KAction( i18n( "New Camera View" ), 0, TQT_TQOBJECT(this),
+ m_pNewCameraViewAction = new TDEAction( i18n( "New Camera View" ), 0, TQT_TQOBJECT(this),
TQT_SLOT( slotNewCameraView( ) ),
actionCollection( ), "view_new_cameraview" );
- m_pNewTreeViewAction = new KAction( i18n( "New Object Tree" ), 0, TQT_TQOBJECT(this),
+ m_pNewTreeViewAction = new TDEAction( i18n( "New Object Tree" ), 0, TQT_TQOBJECT(this),
TQT_SLOT( slotNewTreeView( ) ), actionCollection( ),
"view_new_treeview" );
- m_pNewDialogViewAction = new KAction( i18n( "New Properties View" ), 0, TQT_TQOBJECT(this),
+ m_pNewDialogViewAction = new TDEAction( i18n( "New Properties View" ), 0, TQT_TQOBJECT(this),
TQT_SLOT( slotNewDialogView( ) ), actionCollection( ),
"view_new_dialogview" );
#ifdef KPM_WITH_OBJECT_LIBRARY
- m_pNewLibraryBrowserAction = new KAction( i18n( "New Library Browser" ), 0, TQT_TQOBJECT(this),
+ m_pNewLibraryBrowserAction = new TDEAction( i18n( "New Library Browser" ), 0, TQT_TQOBJECT(this),
TQT_SLOT( slotNewLibraryBrowserView( ) ), actionCollection( ),
"view_new_librarybrowser" );
#endif
// Creating the view layouts menu
- m_pViewLayoutsAction = new KActionMenu( i18n( "View Layouts" ),
+ m_pViewLayoutsAction = new TDEActionMenu( i18n( "View Layouts" ),
actionCollection( ), "view_layouts_menu" );
- KPopupMenu* menu = m_pViewLayoutsAction->popupMenu( );
+ TDEPopupMenu* menu = m_pViewLayoutsAction->popupMenu( );
connect( menu, TQT_SIGNAL( aboutToShow( ) ), TQT_SLOT( slotViewsMenuAboutToShow( ) ) );
PMViewLayoutManager::theManager( )->fillPopupMenu( menu );
connect( menu, TQT_SIGNAL( activated( int ) ), TQT_SLOT( slotSelectedLayout( int ) ) );
- m_pSaveViewLayoutAction = new KAction( i18n( "Save View Layout..." ), 0, TQT_TQOBJECT(this),
+ m_pSaveViewLayoutAction = new TDEAction( i18n( "Save View Layout..." ), 0, TQT_TQOBJECT(this),
TQT_SLOT( slotSaveViewLayout( ) ),
actionCollection( ), "save_view_layout" );
}
@@ -607,7 +607,7 @@ void PMShell::setCaption( const TQString& caption )
tmp = caption;
}
- KMainWindow::setCaption( tmp, m_pPart->isModified( ) );
+ TDEMainWindow::setCaption( tmp, m_pPart->isModified( ) );
}
void PMShell::statusMsg( const TQString& text )
@@ -668,7 +668,7 @@ void PMShell::slotSaveViewLayout( )
void PMShell::slotViewsMenuAboutToShow( )
{
- KPopupMenu* menu = m_pViewLayoutsAction->popupMenu( );
+ TDEPopupMenu* menu = m_pViewLayoutsAction->popupMenu( );
PMViewLayoutManager::theManager( )->fillPopupMenu( menu );
}
diff --git a/kpovmodeler/pmshell.h b/kpovmodeler/pmshell.h
index 1192a76d..8e354706 100644
--- a/kpovmodeler/pmshell.h
+++ b/kpovmodeler/pmshell.h
@@ -30,11 +30,11 @@
//class KHelpMenu;
class KStatusBar;
-class KListAction;
-class KToggleAction;
-class KSelectAction;
-class KRecentFilesAction;
-class KActionMenu;
+class TDEListAction;
+class TDEToggleAction;
+class TDESelectAction;
+class TDERecentFilesAction;
+class TDEActionMenu;
class PMViewOptions;
/**
@@ -143,24 +143,24 @@ public:
//PMDockWidget* create3DView( PMGLView::PMViewType );
private:
- KRecentFilesAction* m_pRecent;
- KToggleAction* m_pToolbarAction;
- KToggleAction* m_pStatusbarAction;
- KToggleAction* m_pPathAction;
-
- KAction* m_pNewTreeViewAction;
- KAction* m_pNewDialogViewAction;
- KAction* m_pNewTopViewAction;
- KAction* m_pNewBottomViewAction;
- KAction* m_pNewLeftViewAction;
- KAction* m_pNewRightViewAction;
- KAction* m_pNewFrontViewAction;
- KAction* m_pNewBackViewAction;
- KAction* m_pNewCameraViewAction;
- KAction* m_pNewLibraryBrowserAction;
-
- KActionMenu* m_pViewLayoutsAction;
- KAction* m_pSaveViewLayoutAction;
+ TDERecentFilesAction* m_pRecent;
+ TDEToggleAction* m_pToolbarAction;
+ TDEToggleAction* m_pStatusbarAction;
+ TDEToggleAction* m_pPathAction;
+
+ TDEAction* m_pNewTreeViewAction;
+ TDEAction* m_pNewDialogViewAction;
+ TDEAction* m_pNewTopViewAction;
+ TDEAction* m_pNewBottomViewAction;
+ TDEAction* m_pNewLeftViewAction;
+ TDEAction* m_pNewRightViewAction;
+ TDEAction* m_pNewFrontViewAction;
+ TDEAction* m_pNewBackViewAction;
+ TDEAction* m_pNewCameraViewAction;
+ TDEAction* m_pNewLibraryBrowserAction;
+
+ TDEActionMenu* m_pViewLayoutsAction;
+ TDEAction* m_pSaveViewLayoutAction;
KStatusBar* m_pStatusBar;
PMPart* m_pPart;
diff --git a/kpovmodeler/pmviewlayoutmanager.cpp b/kpovmodeler/pmviewlayoutmanager.cpp
index b6d72b3c..f8e1c968 100644
--- a/kpovmodeler/pmviewlayoutmanager.cpp
+++ b/kpovmodeler/pmviewlayoutmanager.cpp
@@ -832,7 +832,7 @@ PMViewLayout* PMViewLayoutManager::findLayout( const TQString& name )
return &( *it );
}
-void PMViewLayoutManager::fillPopupMenu( KPopupMenu* pMenu )
+void PMViewLayoutManager::fillPopupMenu( TDEPopupMenu* pMenu )
{
TQStringList lst = availableLayouts( );
TQStringList::ConstIterator it = lst.begin( );
diff --git a/kpovmodeler/pmviewlayoutmanager.h b/kpovmodeler/pmviewlayoutmanager.h
index 9cfdee67..bef34168 100644
--- a/kpovmodeler/pmviewlayoutmanager.h
+++ b/kpovmodeler/pmviewlayoutmanager.h
@@ -271,7 +271,7 @@ public:
/**
* Fill the available layouts menu
*/
- void fillPopupMenu( KPopupMenu* pMenu );
+ void fillPopupMenu( TDEPopupMenu* pMenu );
private:
/**
* Constructor
diff --git a/kpovmodeler/pmdockwidget.cpp b/kpovmodeler/pmdockwidget.cpp
index d92ab0bc..987f6a8c 100644
--- a/kpovmodeler/pmdockwidget.cpp
+++ b/kpovmodeler/pmdockwidget.cpp
@@ -126,7 +126,7 @@ public:
/**
* A special kind of KMainWindow that is able to have dockwidget child widgets.
*
* The main widget should be a dockwidget where other dockwidgets can be docked to
* the left, right, top, bottom or to the middle.
@@ -135,7 +135,7 @@ public:
* @author Max Judin.
*/
PMDockMainWindow::PMDockMainWindow( TQWidget* parent, const char *name, WFlags f)
-:KMainWindow( parent, name, f )
+:TDEMainWindow( parent, name, f )
{
TQString new_name = TQString(name) + TQString("_DockManager");
dockManager = new PMDockManager( this, new_name.latin1() );
@@ -260,7 +260,7 @@ void PMDockMainWindow::setView( TQWidget *view )
}
#ifndef NO_KDE2
- KMainWindow::setCentralWidget(view);
+ TDEMainWindow::setCentralWidget(view);
#else
TQMainWindow::setCentralWidget(view);
#endif
@@ -1271,7 +1271,7 @@ PMDockManager::PMDockManager( TQWidget* mainWindow , const char* name )
menuData->setAutoDelete( true );
#ifndef NO_KDE2
- menu = new KPopupMenu();
+ menu = new TDEPopupMenu();
#else
menu = new TQPopupMenu();
#endif
@@ -2540,10 +2540,10 @@ void PMDockManager::virtual_hook( int, void* )
{ /*BASE::virtual_hook( id, data );*/ }
void PMDockMainWindow::virtual_hook( int id, void* data )
-{ KMainWindow::virtual_hook( id, data ); }
+{ TDEMainWindow::virtual_hook( id, data ); }
void PMDockArea::virtual_hook( int, void* )
-{ /*KMainWindow::virtual_hook( id, data );*/ }
+{ /*TDEMainWindow::virtual_hook( id, data );*/ }
#ifndef NO_INCLUDE_MOCFILES // for TQt-only projects, because tmake doesn't take this name
@@ -126,7 +126,7 @@ public:
/**
- * A special kind of KMainWindow that is able to have dockwidget child widgets.
+ * A special kind of TDEMainWindow that is able to have dockwidget child widgets.
*
* The main widget should be a dockwidget where other dockwidgets can be docked to
diff --git a/kpovmodeler/pmdockwidget.h b/kpovmodeler/pmdockwidget.h
index 18aa1db6..04a43ef9 100644
--- a/kpovmodeler/pmdockwidget.h
+++ b/kpovmodeler/pmdockwidget.h
@@ -38,7 +38,7 @@
- PMDockTabGroup - minor helper class
- PMDockWidget - IMPORTANT CLASS: the one and only dockwidget class
- PMDockManager - helper class
- - PMDockMainWindow - IMPORTANT CLASS: a special KMainWindow that can have dockwidgets
+ - PMDockMainWindow - IMPORTANT CLASS: a special TDEMainWindow that can have dockwidgets
- PMDockArea - like PMDockMainWindow but inherits just TQWidget
IMPORTANT Note: This file compiles also in TQt-only mode by using the NO_KDE2 precompiler definition!
@@ -93,7 +93,7 @@ class TQHBoxLayout;
class TQPixmap;
#ifndef NO_KDE2
-class KToolBar;
+class TDEToolBar;
class TDEConfig;
#else
class TQToolBar;
@@ -1170,7 +1170,7 @@ private:
};
/**
* A special kind of @ref KMainWindow that is able to have dockwidget child widgets (and member of the dockwidget class set).
*
* The main widget should be a @ref PMDockWidget where other @ref PMDockWidget can be docked to
* the left, right, top, bottom or to the middle.
@@ -1212,7 +1212,7 @@ private:
*
* @author Max Judin (documentation: Falk Brettschneider).
*/
-class EXPORT_DOCKCLASS PMDockMainWindow : public KMainWindow, virtual public PartBase
+class EXPORT_DOCKCLASS PMDockMainWindow : public TDEMainWindow, virtual public PartBase
{
Q_OBJECT
@@ -1414,7 +1414,7 @@ private:
#ifdef _JOWENN_EXPERIMENTAL_
/* Joseph Wenninger jowenn@kde.org Experimental (Just all KMainWindow references changed to TQWidget, otherwise nearly exactly the
same as PMDockMainWindow*/
class EXPORT_DOCKCLASS PMDockArea : public TQWidget
@@ -1170,7 +1170,7 @@ private:
};
/**
- * A special kind of @ref KMainWindow that is able to have dockwidget child widgets (and member of the dockwidget class set).
+ * A special kind of @ref TDEMainWindow that is able to have dockwidget child widgets (and member of the dockwidget class set).
*
* The main widget should be a @ref PMDockWidget where other @ref PMDockWidget can be docked to
@@ -1414,7 +1414,7 @@ private:
#ifdef _JOWENN_EXPERIMENTAL_
-/* Joseph Wenninger jowenn@kde.org Experimental (Just all KMainWindow references changed to TQWidget, otherwise nearly exactly the
+/* Joseph Wenninger jowenn@kde.org Experimental (Just all TDEMainWindow references changed to TQWidget, otherwise nearly exactly the
same as PMDockMainWindow*/
class EXPORT_DOCKCLASS PMDockArea : public TQWidget